@@ -16,7 +16,7 @@ test_that("effect_counts_one", {
     data |>
       dplyr::filter(sd_gender != "diverse") |>
       volker::effect_counts(sd_gender),
-    cran= TRUE
+    cran = TRUE
   )
 
 })
@@ -26,9 +26,9 @@ test_that("effect_counts_one_grouped", {
   expect_snapshot(
     data |>
       dplyr::filter(sd_gender != "diverse") |>
-      dplyr::mutate(sd_age = ifelse(sd_age >40,"+40","-40")) |>
-      volker::effect_counts(sd_gender, sd_age),
-    cran= TRUE
+      dplyr::mutate(sd_age_group = ifelse(sd_age > 40,"40+","< 40")) |>
+      volker::effect_counts(sd_gender, sd_age_group),
+    cran = TRUE
   )
 
 })
@@ -40,32 +40,32 @@ data |>
 # Metric
 
 test_that("effect_metrics_one", {
-  expect_snapshot(volker::effect_metrics(data, sd_age), cran= TRUE)
+  expect_snapshot(volker::effect_metrics(data, sd_age), cran = TRUE)
 })
 
 test_that("effect_metrics_one_grouped", {
-  expect_snapshot(volker::effect_metrics(data, sd_age, adopter), cran= TRUE)
+  expect_snapshot(volker::effect_metrics(data, sd_age, adopter), cran = TRUE)
 })
 
 test_that("effect_metrics_one_cor", {
-  expect_snapshot(volker::effect_metrics(data, sd_age, use_private, metric=TRUE), cran= TRUE)
+  expect_snapshot(volker::effect_metrics(data, sd_age, use_private, metric=TRUE), cran = TRUE)
 })
 
 test_that("effect_metrics_one_cor with pearson", {
-  expect_snapshot(volker::effect_metrics(data, sd_age, use_private, metric=TRUE, method="pearson"), cran= TRUE)
+  expect_snapshot(volker::effect_metrics(data, sd_age, use_private, metric=TRUE, method="pearson"), cran = TRUE)
 })
 
 
 test_that("effect_metrics_one_cor with spearman", {
-  expect_snapshot(volker::effect_metrics(data, sd_age, use_private, metric=TRUE, method="spearman"), cran= TRUE)
+  expect_snapshot(volker::effect_metrics(data, sd_age, use_private, metric=TRUE, method="spearman"), cran = TRUE)
 })
 
 test_that("effect_metrics_items", {
-  expect_snapshot(volker::effect_metrics(data, tidyselect::starts_with("use_")), cran= TRUE)
+  expect_snapshot(volker::effect_metrics(data, tidyselect::starts_with("use_")), cran = TRUE)
 })
 
 test_that("effect_metrics_items_cor with one variable", {
-  expect_snapshot(volker::effect_metrics(data, tidyselect::starts_with("cg_adoption_"), sd_age, metric=TRUE), cran= TRUE)
+  expect_snapshot(volker::effect_metrics(data, tidyselect::starts_with("cg_adoption_"), sd_age, metric=TRUE), cran = TRUE)
 })
 
 test_that("effect_metrics_items_cor with one variable and spearman", {
@@ -76,7 +76,7 @@ test_that("effect_metrics_items_cor with one variable and spearman", {
       sd_age,metric=TRUE,
       method = "spearman"
       ),
-     cran= TRUE)
+     cran = TRUE)
 })
 
 test_that("effect_metrics_items_cor with items", {
@@ -86,7 +86,7 @@ test_that("effect_metrics_items_cor with items", {
       tidyselect::starts_with("cg_adoption_"),
       tidyselect::starts_with("cg_adoption_"),
       metric=TRUE
-    ), cran= TRUE
+    ), cran = TRUE
   )
 })
 
@@ -97,7 +97,7 @@ test_that("effect_metrics_items_cor_items with two batteries", {
       tidyselect::starts_with("cg_adoption_"),
       tidyselect::starts_with("use_"),
       metric=TRUE
-    ), cran= TRUE
+    ), cran = TRUE
   )
 })
 
@@ -109,6 +109,6 @@ test_that("effect_metrics_items_cor_items with spearman", {
       tidyselect::starts_with("use_"),
       metric=TRUE,
       method= "spearman"
-    ), cran= TRUE
+    ), cran = TRUE
   )
 })
